[Python-checkins] [3.12] gh-106194: Rename duplicated tests in `test_curses` (GH-106196) (#106216)

hugovk webhook-mailer at python.org
Wed Jun 28 17:12:16 EDT 2023


https://github.com/python/cpython/commit/e12045d64853ddfd5f4dbf193270b644de3b8d9a
commit: e12045d64853ddfd5f4dbf193270b644de3b8d9a
branch: 3.12
author: Miss Islington (bot) <31488909+miss-islington at users.noreply.github.com>
committer: hugovk <hugovk at users.noreply.github.com>
date: 2023-06-28T21:12:12Z
summary:

[3.12] gh-106194: Rename duplicated tests in `test_curses` (GH-106196) (#106216)

Co-authored-by: Nikita Sobolev <mail at sobolevn.me>

files:
M Lib/test/test_curses.py

diff --git a/Lib/test/test_curses.py b/Lib/test/test_curses.py
index 3ab837e4f9568..31bc108e7712e 100644
--- a/Lib/test/test_curses.py
+++ b/Lib/test/test_curses.py
@@ -1364,26 +1364,33 @@ def test_move_left(self):
         self.mock_win.reset_mock()
         self.textbox.do_command(curses.KEY_LEFT)
         self.mock_win.move.assert_called_with(1, 0)
+        self.mock_win.reset_mock()
+
+    def test_move_right(self):
+        """Test moving the cursor right."""
+        self.mock_win.reset_mock()
         self.textbox.do_command(curses.KEY_RIGHT)
         self.mock_win.move.assert_called_with(1, 2)
         self.mock_win.reset_mock()
 
-    def test_move_left(self):
-        """Test moving the cursor left."""
+    def test_move_left_and_right(self):
+        """Test moving the cursor left and then right."""
         self.mock_win.reset_mock()
+        self.textbox.do_command(curses.KEY_LEFT)
+        self.mock_win.move.assert_called_with(1, 0)
         self.textbox.do_command(curses.KEY_RIGHT)
         self.mock_win.move.assert_called_with(1, 2)
         self.mock_win.reset_mock()
 
     def test_move_up(self):
-        """Test moving the cursor left."""
+        """Test moving the cursor up."""
         self.mock_win.reset_mock()
         self.textbox.do_command(curses.KEY_UP)
         self.mock_win.move.assert_called_with(0, 1)
         self.mock_win.reset_mock()
 
     def test_move_down(self):
-        """Test moving the cursor left."""
+        """Test moving the cursor down."""
         self.mock_win.reset_mock()
         self.textbox.do_command(curses.KEY_DOWN)
         self.mock_win.move.assert_called_with(2, 1)



More information about the Python-checkins mailing list